patchelf: A small utility to modify the dynamic linker and RPATH of ELF executables
===================================================================================

Description
-----------

A small utility to modify the dynamic linker and RPATH of ELF executables.

License
-------

GPL-3.0-or-later

Upstream Contact
----------------

https://github.com/NixOS/patchelf
